% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/TSSEscore.R
\name{TSSEscore}
\alias{TSSEscore}
\title{Transcription Start Site (TSS) Enrichment Score}
\usage{
TSSEscore(obj, txs, seqlev = intersect(seqlevels(obj), seqlevels(txs)),
  upstream = 1000, downstream = 1000, endSize = 100)
}
\arguments{
\item{obj}{an object of \link[GenomicAlignments:GAlignments-class]{GAlignments}}

\item{txs}{GRanges of transcripts}

\item{seqlev}{A vector of characters indicates the sequence levels.}

\item{upstream, downstream}{numeric(1) or integer(1). upstream and downstream of TSS. Default is 1000}

\item{endSize}{numeric(1) or integer(1). the size of the end flanks. Default is 100}
}
\value{
A object of \link[GenomicRanges:GRanges-class]{GRanges} with TSS scores
}
\description{
TSS score is a raio between aggregate distribution of reads centered on TSSs and that flanking 
the corresponding TSSs. TSS score = the depth of TSS (1000 bp each side) / the depth of end flanks (100bp each end).
}
\examples{
 
library(GenomicRanges)
bamfile <- system.file("extdata", "GL1.bam", 
                       package="ATACseqQC", mustWork=TRUE)
gal1 <- readBamFile(bamFile=bamfile, tag=character(0), 
                    which=GRanges("chr1", IRanges(1, 1e6)), 
                    asMates=FALSE)
library(TxDb.Hsapiens.UCSC.hg19.knownGene)
txs <- transcripts(TxDb.Hsapiens.UCSC.hg19.knownGene)
tsse <- TSSEscore(gal1, txs)
}
\references{
https://www.encodeproject.org/data-standards/terms/#enrichment
}
\author{
Jianhong Ou
}
